# About

Tagmaps package is maintained by Alexander Dunkel. He is a landscape architect and landscape planner with focus on data analysis and visualization.

Found any errors or bugs? Please use the issue reporting on [Github](https://github.com/Sieboldianus/TagMaps)

Tag Maps docs built with [mkdocs](https://github.com/mkdocs/mkdocs) and [ReadTheDocs theme](https://github.com/mkdocs/mkdocs/tree/master/mkdocs/themes/readthedocs).

Tag Maps is developed under open source GNU GPLv3 License.